function class = classify(signal, models, timeLag, dimension)

% class = classify(timeSeries, models, timeLag, dimension)
%
% Input Variables
%       signal - a time series
%       models - GMM models for the various classes
%       timeLag - time lag to use for the reconstructed phase spaces
%       dimension - dimension to use for the reconstructed phase spaces
%
% Output Variables
%       class - the estimated class of the signal
%
% Language - MATLAB
%  
% Description:  Classify the signal using the models
%
% Created:     
%               Date: 6/20/2003  
%               By:  Richard J. Povinelli
%               Marquette University
%
% Modified:    
%               Version:
%               Date: 
%               By: 
%               Why: 

% normalize the signal to zero mean and unit variance
signalMean = mean(signal);
signalStd = std(signal);
signal = (signal - signalMean)/signalStd;

%form a reconstructed phase space and insert signal
lags = createLags(dimension,timeLag);
rps = embed(signal,lags);

labels = models(:,1); %copies the labels for all the models
numberOfClasses = length(labels); %find the number of classes

%calculate the log probability of each class
logProbabilities = ones(numberOfClasses,1) * -Inf;
for i = 1:numberOfClasses 
  logProbabilities(i) = gmmemTest(models{i,2},rps');
end %for

[maxProb maxIndex] = max(logProbabilities);
class = models{maxIndex,1};

return