function class = classifyTDNN(signal, models, dimension)

% class = classifyTDNN(timeSeries, models, timeLag, dimension)
%
% Input Variables
%       signal - a time series
%       models - TDNN models for the various classes
%       dimension - dimension to use for the reconstructed phase spaces
%
% Output Variables
%       class - the estimated class of the signal
%
% Language - MATLAB
%  
% Description:  Classify the signal using the models
%
% Created:     
%               Date: 7/1/2003  
%               By:  Richard J. Povinelli
%               Marquette University
%
% Modified:    
%               Version:
%               Date: 
%               By: 
%               Why: 

% normalize the signal to zero mean and unit variance
signalMean = mean(signal);
signalStd = std(signal);
signal = (signal - signalMean)/signalStd;

%form a reconstructed phase space and insert signal
lags = createLags(dimension + 1,1); %use this to create the target vector also
rps = embed(signal,lags);
p = rps(1:dimension,:); %strip of the first dimension rows as the testing
target = rps(dimension + 1,:); %use the last row as the target

labels = models(:,1); %copies the labels for all the models
numberOfClasses = length(labels); %find the number of classes

%calculate the log probability of each class
sse = ones(numberOfClasses,1) * Inf;
for i = 1:numberOfClasses 
  tdnnOutput = sim(models{i,2},p);
  sse(i) = sum((target - tdnnOutput).^2);
end %for

[minSSE minIndex] = min(sse);
class = models{minIndex,1};

return