function [leaveInTimeSeries, leaveOutTimeSeries] = ...
  createFoldSets(timeSeries,foldsIndices,leaveOutFold)
% [classTimeSeries, leaveOutTimeSeries] = createFoldSets(timeSeries,foldsIndices,leaveOutFold)
%
% Input Variables
%       timeSeries - all the signals and their labels - a two dimensional cell array. The
%                   first cell is a text label for the second cell. The second 
%                   cell is a time series.
%       foldsIndices - the indices for each fold
%       leaveOutFold - the fold to leave out
%
% Output Variables
%       leaveInTimeSeries - all the signals NOT in the leave out fold
%       leaveOutTimeSeries - all the signals in the leave out fold
%
% Language - MATLAB
%  
% Description:  Creates the training and testing sets of time series from
%               the definition of the folds
%
% Created:     
%               Date: 6/20/2003  
%               By:  Richard J. Povinelli
%               Marquette University
%
% Modified:    
%               Version:
%               Date: 
%               By: 
%               Why: 


numberOfFolds = length(foldsIndices);
inFoldIndices = [];
outFoldIndices = [];

%combine the indices
for i = 1:numberOfFolds
  if i ~= leaveOutFold
    inFoldIndices = [inFoldIndices foldsIndices{i}]; %collect all the in fold indices
  else
    outFoldIndices = foldsIndices{i}; %collect all the out fold indices  
  end %ifelse
end %for

%pre allocate memory
inFoldSize = length(inFoldIndices);
outFoldSize = length(outFoldIndices);
leaveInTimeSeries = cell(inFoldSize,2);
leaveOutTimeSeries = cell(outFoldSize,2);

%create the leaveInTimeSeries cell array
for i = 1:inFoldSize
%     inFoldSize
%     inFoldIndices(i)
  leaveInTimeSeries(i,:) = timeSeries(inFoldIndices(i),:);
end %for

%create the leaveOutTimeSeries cell array
for i = 1:outFoldSize
  leaveOutTimeSeries(i,:) = timeSeries(outFoldIndices(i),:);
end %for

return
